@@ -3,6 +3,12 @@ from sqlalchemy.dialects.postgresql.base import ischema_names
 
 
 class TSVectorType(sa.types.UserDefinedType):
+    class comparator_factory(sa.types.TypeEngine.Comparator):
+        def match(self, other):
+            from sqlalchemy_utils.expressions import tsvector_match
+
+            return tsvector_match(self.expr, other)
+
     def __init__(self, *args, **kwargs):
         """
         Initializes new TSVectorType
